==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__242.h <==
// final class javax.swing.colorchooser.DefaultHSBChooserPanel$2

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class eed084c570fbd3cc javax_swing_colorchooser_DefaultHSBChooserPanel__242

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__242_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__242_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *);

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *);
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *, struct _jc_java_awt_Graphics$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method_info$paint$76f038a09cf0c480;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *, struct _jc_java_awt_Graphics$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__242;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__242;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__242;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__242_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__242.h <==
// final class javax.swing.colorchooser.DefaultHSBChooserPanel$2

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 3a96578ee648a88e javax_swing_colorchooser_DefaultHSBChooserPanel__242

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__242_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__242_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$method_info$paint$76f038a09cf0c480;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__242;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__242;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__242;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__242$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__242_H_ */
